@@ -24,6 +24,20 @@ function graph_save_snippet() {
         });
 }
 
+function graph_action_reload() {
+    // send all graph properties to server and reload page
+    var $form, url;
+    $form = $(this).parents("form.graph-options");
+    url = $form.attr("data-url");
+    $.post(
+        url,
+        $form.serialize(),
+        function () {
+            // Always reload page: statistics & graphs can be different.
+            location.reload();
+        });
+}
+
 function graph_action() {
     // send all graph properties to server and reload graphs
     var $form, url;
@@ -38,8 +52,31 @@ function graph_action() {
         });
 }
 
+function setGraphFilterMonth() {
+    var $form, status;
+    $form = $(".popup-graph-edit-global");
+    $form.each(function () {
+        status = $(this).find("input:radio:checked").attr("value");
+        if (status === "4") { // 4 is "MONTH"
+            $(this).find(".graph-filter-month").attr("disabled", false);
+        } else {
+            $(this).find(".graph-filter-month").attr("disabled", true);
+        }
+    });
+}
+
+function setUpGraphForm() {
+    // Set current status.
+    setGraphFilterMonth();
+
+    // Setup click.
+    $(".popup-graph-edit-global input:radio").click(setGraphFilterMonth);
+}
+
 $(document).ready(function () {
     $(".graph-save-snippet").bind("click", graph_save_snippet);
     $(".graph-action").bind("click", graph_action);
-    graph_action();  // update graph with current options
+    $(".graph-action-reload").bind("click", graph_action_reload);
+    //graph_action();  // update graph with current options
+    setUpGraphForm();
 });
