@@ -9,6 +9,14 @@ from django.utils.translation import ugettext as _
 import pkg_resources
 
 from lizard_map.adapter import parse_identifier_json
+from lizard_map.dateperiods import ALL
+from lizard_map.dateperiods import YEAR
+from lizard_map.dateperiods import QUARTER
+from lizard_map.dateperiods import MONTH
+from lizard_map.dateperiods import WEEK
+from lizard_map.dateperiods import DAY
+from lizard_map.dateperiods import calc_aggregation_periods
+from lizard_map.dateperiods import fancy_period
 
 # Do not change the following items!
 GROUPING_HINT = 'grouping_hint'
@@ -21,13 +29,6 @@ ADAPTER_ENTRY_POINT = 'lizard_map.adapter_class'
 SEARCH_ENTRY_POINT = 'lizard_map.search_method'
 LOCATION_ENTRY_POINT = 'lizard_map.location_method'
 
-ALL = 1
-YEAR = 2
-QUARTER = 3
-MONTH = 4
-WEEK = 5
-DAY = 6
-
 logger = logging.getLogger('lizard_map.models')
 
 
@@ -237,8 +238,12 @@ class WorkspaceCollageSnippetGroup(models.Model):
     index = models.IntegerField(default=1000)  # larger = lower in the list
     name = models.CharField(max_length=80, blank=True, null=True)
 
-    # boundary value for statistics
+    # Boundary value for statistics.
     boundary_value = models.FloatField(blank=True, null=True)
+    # Percentile value for statistics.
+    percentile_value = models.FloatField(blank=True, null=True)
+    # Restrict_to_month is used to filter the data.
+    restrict_to_month = models.IntegerField(blank=True, null=True)
     aggregation_period = models.IntegerField(
         choices=AGGREGATION_PERIOD_CHOICES, default=ALL)
 
@@ -271,36 +276,41 @@ class WorkspaceCollageSnippetGroup(models.Model):
     def statistics(self, start_date, end_date):
         """
         Calcs standard statistics: min, max, avg, count_lt, count_gte,
-        percentile 25, percentile 75 and return them in a list of dicts
+        percentile and return them in a list of dicts
+
+        Can be filtered by option restrict_to_month.
         """
         statistics = []
         for snippet in self.snippets.all():
             snippet_adapter = snippet.workspace_item.adapter
 
-            # base statistics
-            statistics_row = snippet_adapter.value_aggregate(
-                snippet.identifier,
-                {'min': None, 'max': None, 'avg': None,
-                 'count_lt': self.boundary_value,
-                 'count_gte': self.boundary_value,
-                 'percentile': 25},
-                start_date=start_date,
-                end_date=end_date)
-            # add 75 percentile
-            statistics_percentile75 = snippet_adapter.value_aggregate(
-                snippet.identifier,
-                {'percentile': 75},
-                start_date=start_date,
-                end_date=end_date)
-            if 'percentile' in statistics_percentile75:
-                statistics_row.update(
-                    {'percentile_75':
-                         statistics_percentile75['percentile']})
+            # Calc periods based on aggregation period setting.
+            periods = calc_aggregation_periods(start_date, end_date,
+                                               self.aggregation_period)
 
-            # add name
-            if statistics_row:
-                statistics_row['name'] = snippet.name
-                statistics.append(statistics_row)
+            for period_start_date, period_end_date in periods:
+                if not self.restrict_to_month or (
+                    self.aggregation_period != MONTH) or (
+                    self.aggregation_period == MONTH and
+                    self.restrict_to_month == period_start_date.month):
+
+                    # Base statistics for each period.
+                    statistics_row = snippet_adapter.value_aggregate(
+                        snippet.identifier,
+                        {'min': None, 'max': None, 'avg': None,
+                         'count_lt': self.boundary_value,
+                         'count_gte': self.boundary_value,
+                         'percentile': self.percentile_value},
+                        start_date=period_start_date,
+                        end_date=period_end_date)
+
+                    # Add name.
+                    if statistics_row:
+                        statistics_row['name'] = snippet.name
+                        statistics_row['period'] = fancy_period(
+                            period_start_date, period_end_date,
+                            self.aggregation_period)
+                        statistics.append(statistics_row)
 
         return statistics
 
@@ -308,6 +318,8 @@ class WorkspaceCollageSnippetGroup(models.Model):
         """
         Calculates a table with each location as column, each row as
         datetime. First row consist of column names. List of lists.
+
+        Can be filtered by option restrict_to_month.
         """
         values_table = []
 
@@ -331,7 +343,12 @@ class WorkspaceCollageSnippetGroup(models.Model):
             snippet_values[snippet.id] = {}
             # Translate list into dict with dates.
             for row in values:
-                snippet_values[snippet.id][row['datetime']] = row
+                if not self.restrict_to_month or (
+                    self.aggregation_period != MONTH) or (
+                    self.aggregation_period == MONTH and
+                    row['datetime'].month == self.restrict_to_month):
+
+                    snippet_values[snippet.id][row['datetime']] = row
             found_dates.update(snippet_values[snippet.id])
             # ^^^ The value doesn't matter.
 
@@ -362,6 +379,8 @@ class WorkspaceCollageSnippetGroup(models.Model):
             result['y_max'] = self.layout_y_max
         if self.layout_title:
             result['title'] = self.layout_title
+        if self.restrict_to_month:
+            result['restrict_to_month'] = self.restrict_to_month
         if self.boundary_value is not None:
             result['horizontal_lines'] = [{
                     'name': _('Boundary value'),
@@ -370,6 +389,16 @@ class WorkspaceCollageSnippetGroup(models.Model):
                               'linestyle': '--',
                               'color': 'green'},
                     }, ]
+        # TODO: implement percentile. Start/end date is not known here.
+        # if self.percentile_value is not None:
+        #     calculated_percentile = self.statistics(self.percentile_value,,)
+        #     result['horizontal_lines'] = [{
+        #             'name': _('Percentile value'),
+        #             'value': calculated_percentile,
+        #             'style': {'linewidth': 2,
+        #                       'linestyle': '--',
+        #                       'color': 'green'},
+        #             }, ]
         return result
 
 
