@@ -141,6 +141,21 @@ def workspace_item_edit(request, workspace_item_id=None, visible=None):
 def snippet_group_graph_edit(request, snippet_group_id):
     """Edits snippet_group properties using post.
     """
+    restrict_to_month_lookup = {
+        'no-restriction': None,
+        'januari': 1,
+        'februari': 2,
+        'march': 3,
+        'april': 4,
+        'may': 5,
+        'june': 6,
+        'july': 7,
+        'august': 8,
+        'september': 9,
+        'october': 10,
+        'november': 11,
+        'december': 12}
+
     post = request.POST
     title = post.get('title', None)
     x_label = post.get('x_label', None)
@@ -148,7 +163,10 @@ def snippet_group_graph_edit(request, snippet_group_id):
     y_min = post.get('y_min', None)
     y_max = post.get('y_max', None)
     boundary_value = post.get('boundary_value', None)
+    percentile_value = post.get('percentile_value', None)
     aggregation_period = post.get('aggregation_period', None)
+    restrict_to_month = restrict_to_month_lookup[
+        post.get('restrict_to_month', 'no-restriction')]
 
     snippet_group = WorkspaceCollageSnippetGroup.objects.get(
         pk=snippet_group_id)
@@ -159,6 +177,7 @@ def snippet_group_graph_edit(request, snippet_group_id):
         snippet_group.layout_x_label = x_label
     if y_label is not None:
         snippet_group.layout_y_label = y_label
+    snippet_group.restrict_to_month = restrict_to_month
     if aggregation_period is not None:
         snippet_group.aggregation_period = int(aggregation_period)
     try:
@@ -173,6 +192,10 @@ def snippet_group_graph_edit(request, snippet_group_id):
         snippet_group.boundary_value = float(boundary_value)
     except (ValueError, TypeError):
         snippet_group.boundary_value = None
+    try:
+        snippet_group.percentile_value = float(percentile_value)
+    except (ValueError, TypeError):
+        snippet_group.percentile_value = None
     snippet_group.save()
     return HttpResponse('')
 
@@ -365,6 +388,7 @@ def popup_collage_json(collage, popup_id, request=None):
         big_popup = True
     else:
         big_popup = False
+    google_x, google_y = None, None
 
     for snippet_group in snippet_groups:
         snippets = snippet_group.snippets.all()
@@ -767,15 +791,16 @@ def export_snippet_group_statistics_csv(request, snippet_group_id=None):
     statistics = snippet_group.statistics(start_date, end_date)
 
     response = HttpResponse(mimetype='text/csv')
-    response['Content-Disposition'] = 'attachment; filename=export.csv'
+    response['Content-Disposition'] = ('attachment; '
+                                       'filename=export_statistics.csv')
     writer = csv.writer(response)
     colnames = ['min', 'max', 'avg', 'count_lt',
                 'count_gte',
-                'percentile', 'percentile_75']
+                'percentile']
     colnamesdisplay = ['min', 'max', 'avg',
                        '# < %s' % snippet_group.boundary_value,
                        '# >= %s' % snippet_group.boundary_value,
-                       'percentile_25', 'percentile_75']
+                       'percentile %f' % snippet_group.percentile_value]
     writer.writerow(colnamesdisplay)
     for row in statistics:
         writer.writerow([row[colname] for colname in colnames])
