@@ -1,4 +1,5 @@
 import os
+import logging
 
 from django.conf import settings
 from django.core.urlresolvers import reverse
@@ -10,9 +11,12 @@ from lizard_map.models import DEFAULT_WORKSPACES
 from lizard_map.models import ICON_ORIGINALS
 from lizard_map.models import TEMP_WORKSPACES
 from lizard_map.models import USER_WORKSPACES
+from lizard_map.models import Color
+from lizard_map.models import Legend
 from lizard_map.models import Workspace
 from lizard_map.symbol_manager import SymbolManager
 
+logger = logging.getLogger('lizard_map.workspace')
 
 # The colors that are used in graphs
 COLORS_DEFAULT = [
@@ -35,23 +39,31 @@ class WorkspaceManager:
 
     def save_workspaces(self):
         """save workspaces to session"""
-        workspaces_id = {}
+        workspace_group_ids = {}
         for group, workspace_list in self.workspaces.items():
-            workspaces_id[group] = [workspace.id for workspace in
-                                    workspace_list]
-        self.request.session['workspaces'] = workspaces_id
+            workspace_group_ids[group] = [workspace.id for workspace in
+                                          workspace_list]
+        self.request.session['workspaces'] = workspace_group_ids
+        logger.debug('WorkspaceManager.save_workspaces: saved '
+                     'workspace_group_ids in session.')
 
-    def load_workspaces(self, workspaces_id=None):
+    def load_workspaces(self, workspace_group_ids=None):
         """load workspaces from session
 
+        note: request.session['workspaces'] must be filled before
+        using this function
+
         returns number of workspaces that could not be loaded"""
         errors = 0
-        # TODO: fix up workspaces_id and workspace_ids as those terms are too
-        # similar.  They will lead to coding errors.
-        if workspaces_id is None:
-            workspaces_id = self.request.session['workspaces']
+        if workspace_group_ids is None:
+            if 'workspaces' in self.request.session:
+                workspace_group_ids = self.request.session['workspaces']
+            else:
+                logger.warn(('WorkspaceManager.load_workspaces: no workspaces'
+                             ' in kwargs or in session.'))
+                return 1
         # Workspaces are grouped by key TEMP_WORKSPACES, USER_WORKSPACES, etc.
-        for group, workspace_ids in workspaces_id.items():
+        for group, workspace_ids in workspace_group_ids.items():
             self.workspaces[group] = []
             for workspace_id in workspace_ids:
                 try:
@@ -68,7 +80,7 @@ class WorkspaceManager:
 
     def load_or_create(self, new_workspace=False):
         """load workspaces references by session['workspaces'] or
-        create new workspace
+        create new workspace (saves in case of changes to workspaces)
 
         workspaces are returned in a dictionary:
         {
@@ -233,6 +245,9 @@ class WorkspaceItemAdapter(object):
                             if v >= value:  # value is boundary value
                                 result_value += 1
                 elif key == 'percentile':
+                    if value is None:
+                        result_value = None
+                    else:
                         rank = int(value * len(values_only) / 100.0 + 0.5)
                         result_value = values_only[rank]
                 else:
@@ -278,11 +293,11 @@ class WorkspaceItemAdapter(object):
             style = {'linestyle': '-',
                      'linewidth': 3,
                      'color': color['mapnik'],
-                     'max_linestyle': ':',
+                     'max_linestyle': '--',
                      'max_linewidth': 2,
-                     'min_linestyle': ':',
+                     'min_linestyle': '--',
                      'min_linewidth': 2,
-                     'avg_linestyle': ':',
+                     'avg_linestyle': '--',
                      'avg_linewidth': 2,
                      }  # default
             if 'layout' in identifier:
@@ -337,7 +352,7 @@ class WorkspaceItemAdapter(object):
         can be provided. Default layout_options:
 
         layout_options = {'add_snippet': False,
-                          'editing': False}
+                         'editing': False}
         """
         return 'html output for this adapter is not implemented'
 
@@ -414,7 +429,7 @@ class WorkspaceItemAdapter(object):
                 },
             )
 
-    def legend():
+    def legend(self):
         """
         Returns legend in a list of dictionaries.
 
@@ -422,3 +437,77 @@ class WorkspaceItemAdapter(object):
 
         """
         return []
+
+    def legend_object_default(self, legend_name):
+        """
+        Get legend object. If no appropriate legend was found, a
+        legend object will be created and returned.
+        """
+        found_legend = Legend.objects.find(legend_name)
+        if found_legend is None:
+            # Fallback if no legend found (should not happen)
+            logger.warn("Could not find legend for key '%s', "
+                        "please configure the legend. "
+                        "Now using fallback (red).")
+            color = Color(r=255, g=0, b=0)
+            found_legend = Legend(descriptor="", min_color=color,
+                                  max_color=color, too_low_color=color,
+                                  too_high_color=color)
+
+        return found_legend
+
+    def legend_default(self, legend_object):
+        """Default implementation for legend. Use a fixed formula to
+        calculate legend descriptor, then find corresponding Legend."""
+
+        icon_style_template = {'icon': 'empty.png',
+                               'mask': ('empty_mask.png', ),
+                               'color': (1, 1, 1, 1)}
+        if legend_object is not None:
+            float_format = legend_object.float_format
+            legend_result = []
+
+            # Add < min
+            icon_style = icon_style_template.copy()
+            icon_style.update({
+                    'color': (legend_object.too_low_color.r / 255.0,
+                              legend_object.too_low_color.g / 255.0,
+                              legend_object.too_low_color.b / 255.0,
+                              legend_object.too_low_color.a / 255.0)})
+            img_url = self.symbol_url(icon_style=icon_style)
+            legend_result.append({'img_url': img_url,
+                                  'description': (('< %s' % float_format) %
+                                                  (legend_object.min_value))})
+
+            # Add range
+            for legend_item in legend_object.legend_values():
+                color = legend_item['color']
+                icon_style = icon_style_template.copy()
+                icon_style.update({'color':
+                                   (color.r / 255.0, color.g / 255.0,
+                                    color.b / 255.0, color.a / 255.0)})
+                img_url = self.symbol_url(icon_style=icon_style)
+                legend_row = {'img_url': img_url,
+                              'description': (
+                        ('%s - %s' % (float_format, float_format)) %
+                        (legend_item['low_value'],
+                         legend_item['high_value']))}
+
+                legend_result.append(legend_row)
+
+            # Add > max
+            icon_style = icon_style_template.copy()
+            icon_style.update({
+                    'color': (legend_object.too_high_color.r / 255.0,
+                              legend_object.too_high_color.g / 255.0,
+                              legend_object.too_high_color.b / 255.0,
+                              legend_object.too_high_color.a / 255.0)})
+            img_url = self.symbol_url(icon_style=icon_style)
+            legend_result.append({'img_url': img_url,
+                                  'description': (('> %s' % float_format) %
+                                                  (legend_object.max_value))})
+
+        else:
+            legend_result = [{'img_url': self.symbol_url(),
+                              'description': 'description'}]
+        return legend_result
